import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.geom.*;
import java.util.*;

public class DrawingPanel extends JPanel{
	static final int RADIUS = 5;
	static final int THRESHOLD = 10;
	ArrayList<Point> points;// = new ArrayList<Point>();
	
	public DrawingPanel(){
		MyMouseAdapter mouseAdapter = new MyMouseAdapter();
		addMouseListener (mouseAdapter);
		addMouseMotionListener(mouseAdapter);
	}

	public DrawingPanel(ArrayList<Point> points){
		this(); // call default constructor DrawingPanel() above
		this.points = points;
	}
	
    protected void paintComponent(Graphics graphics){
    	super.paintComponent(graphics);
    	Graphics2D g = (Graphics2D) graphics;
    	
    	g.setPaint (Color.BLACK);
    	if(points!=null)
			for(int i=0; i<points.size(); i++){
				Point point = points.get(i);
	   		  	int x = (int)point.getX()-RADIUS;
	    		  int y = (int)point.getY()-RADIUS;
	    		  g.fillOval(x,y,2*RADIUS,2*RADIUS);
	    	}
    }
    
    
	private class MyMouseAdapter extends MouseAdapter{
	
		public void mousePressed (MouseEvent e){
			if(e.getButton()==MouseEvent.BUTTON1){
				points.add(e.getPoint());
			} else if (e.getButton()==MouseEvent.BUTTON3){
				// Search through list and delete nearest neighbor within some threshold
				int nearestIndex = -1;
				double nearestDistance = Double.MAX_VALUE;
				for(int i=0; i<points.size(); i++){
					Point current = points.get(i);
					if(current.distance(e.getPoint())<nearestDistance){
						nearestIndex = i;
						nearestDistance=current.distance(e.getPoint());
					}
				}
				if(nearestDistance<=THRESHOLD){
					//Delete point
					points.remove(nearestIndex);
				}
			}
			repaint();
		}


	};
	
}